\name{[.caliblist}
\alias{[.caliblist}
\title{ Extract Parts of a Caliblist.}
\description{ The caliblist extends list. The calibstat objects in the list can therefore be accessed like list elements. }
\usage{}
\arguments{
\item{i}{ indices of calibstat object to extract}
\item{x}{ caliblist}
}
\value{
\item{ caliblist }{ caliblist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{[<-.caliblist},
\code{\link[base]{[.list}},
}
\examples{
 data(mvl)
 data(cal)
 print(cal)
 res<-getintcalib(mvl,cal,error=300)
 res<-res[1:10]
 class(res)
 plot(res)
}
\keyword{misc}

\eof
\name{[.massvector}
\alias{[.massvector}
\title{ Extract Parts of an Massvector}
\description{ The massvector extends matrix. The masses and intensities can be accessed like in case of a matrix.  Do not use mv[1:10] (not handled properly) }
\usage{}
\arguments{
\item{i}{ row access}
\item{j}{ column access}
\item{peak}{ object from which to extract elements.}
}
\value{
\item{ xxx }{ If rows are selected then a massvector is returned. If columns are accessed than arrays are returned.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{peaks.massvector}},
\code{\link{mass.massvector}},
\code{\link{mget.massvector}},
}
\examples{
 data(mv1)
 ls()
 mv1[1:10,] # returns a massvector of length 10
 mv1[1:10,1] # the first ten masses are returned.
 mv1[,1] # the masses are returned.
 mv1[,2] # the peak area are returned.
}
\keyword{misc}

\eof
\name{[.massvectorlist}
\alias{[.massvectorlist}
\title{ Extract Parts of an Massvectorlist.}
\description{ The massvectorlist extends list. The massvectors in the massvectorlist can therefore be accessed like list elements. }
\usage{}
\arguments{
\item{i}{ indices of massvectors to extract}
\item{mvl}{ massvectorlist}
}
\value{
\item{ massvectorlist }{ massvectorlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{[<-.massvectorlist},
\code{[<-.list},
}
\examples{
 data(mvl)
 mvl<-mvl[1:10] # returns a massvectorlist of length 10
 mvl
 class(mvl)
}
\keyword{misc}

\eof
\name{[Assing.massvectorlist}
\alias{[Assing.massvectorlist}
\alias{[<-.massvectorlist}
\title{ Replace Parts of Massvectorlist}
\description{ The massvectorlist extends list. The massvectors in the list can therefore be accessed like list elements. }
\usage{}
\arguments{
\item{i}{ elements to replace.}
\item{mvl}{ massvectorlist.}
\item{value}{ replace by value.}
}
\value{
\item{ massvectorlist }{ massvectorlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{[.massvector},
\code{[.list},
}
\examples{
 data(mvl)
 mvl2<-mvl
 mvl2[11:20]<-mvl[1:10]
 compare(mvl[[11]],mvl[[1]])
}
\keyword{misc}

\eof
\name{[[Assing.caliblist}
\alias{[[Assing.caliblist}
\alias{[[<-.caliblist}
\title{ Replace calibstat object in the caliblist.}
\description{ Replace a calibstat object in the caliblist with a different one. }
\usage{}
\arguments{
\item{i}{ index or name (info) of calibstat object to replace}
\item{value}{ object of class calibstat (e.g. calibrestat, calibextstat).}
\item{x}{ caliblist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 data(cal)
 res<-getintcalib(mvl,cal,error=300)
 res[[1]]<-res[[10]]
}
\keyword{misc}

\eof
\name{[[Assing.massvectorlist}
\alias{[[Assing.massvectorlist}
\alias{[[<-.massvectorlist}
\title{ Replace Parts of an Object}
\description{ Replace a massvector in the massvectorlist with a different one. }
\usage{}
\arguments{
\item{i}{ index or name (info) of massvector to replace}
\item{value}{ massvector}
\item{x}{ massvectorlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 data(mv1)
 mvl[[10]]<-mv1
}
\keyword{misc}

\eof
\name{applycalib.calibintlist}
\alias{applycalib.calibintlist}
\title{ Internal Calibration}
\description{ Corrects the massvectors in the massvectorlist \code{mvl} using the error model  of the \code{calibintstat} objects stored in the \code{calibintlist}. }
\usage{\method{applycalib}{calibintlist}(object,mvl,...)}
\arguments{
\item{...}{ further params}
\item{mvl}{ massvectorlist}
\item{object}{ calibintlist}
}
\details{ \bold{Internal calibration} aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ massvectorlist }{ calibrated massvectorlist. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyintcalib.massvectorlist}},
\code{\link{getintcalib.massvectorlist}},
\code{\link{correctinternal.massvectorlist}},
\code{\link{calibintstat}},
\code{\link{caliblist}},
}
\examples{
 data(mvl)
 data(cal)
 res<-getintcalib(mvl,cal,error=300)
 mvl2<-applycalib(res,mvl)
}
\keyword{misc}

\eof
\name{applycalib.calibintstat}
\alias{applycalib.calibintstat}
\title{ Internal Calibration}
\description{ Corrects the massvector for the error model stored in calibintstat object. }
\usage{\method{applycalib}{calibintstat}(object,mv,...)}
\arguments{
\item{...}{ further parameters}
\item{mv}{ massvector}
\item{object}{calibintstat}
}
\details{ \bold{Internal calibration} aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ massvector }{ calibrated massvector. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyintcalib.massvector}},
\code{\link{getintcalib.massvector}},
\code{\link{correctinternal.massvector}},
}
\examples{
 data(mv1)
 data(cal)
 res<-getintcalib(mv1,cal,error=300)
 mv2<- applycalib(res,mv1)
 plot(mv1[,1],mv2[,1]-mv1[,1])
}
\keyword{misc}

\eof
\name{applycalib.calibrelist}
\alias{applycalib.calibrelist}
\title{ Precalibration}
\description{ Uses the error model obtained by the method \code{getrecalib} and stored in a \code{calibrelist}  to correct masses in the massvectorlist. }
\usage{\method{applycalib}{calibrelist}(object,mvl,...)}
\arguments{
\item{...}{ further parameters}
\item{mvl}{ massvectorlist}
\item{object}{ calibrelist}
}
\details{ \bold{Precalibration} method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the \emph{massesvector} can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\value{
\item{ massvectorlist }{ calibrated massvectorlist. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{recalibrate.massvectorlist}},
\code{\link{getrecalib.massvectorlist}},
\code{\link{correctinternal.massvectorlist}},
}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 res<-getrecalib(mvl)
 plot(res)
 image(res,what="PQM")
 mvlr<-applycalib(res,mvl)
}
\keyword{misc}

\eof
\name{applycalib.calibrestat}
\alias{applycalib.calibrestat}
\title{ Precalibration}
\description{ Uses the error model obtained by the method \code{getrecalib} to correct masses in the massvector. }
\usage{\method{applycalib}{calibrestat}(object,mv,...)}
\arguments{
\item{...}{ further arguments}
\item{mv}{ massvector}
\item{object}{ calibrestat}
}
\details{ \bold{Precalibration} method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the \emph{massesvector} can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. \bold{Proteomics.} 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applycalib.calibintstat}},
\code{\link{getrecalib.massvector}},
\code{\link{getrecalib.massvectorlist}},
\code{\link{recalibrate.massvector}},
\code{\link{recalibrate.massvectorlist}},
\code{\link{calibrestat}},
\code{\link{calibrelist}},
}
\examples{
 data(mv1)
 res <- getrecalib(mv1)
 plot(res)
 mv2<-applycalib(res,mv1)
 plot(mv1[,1],mv2[,1]-mv1[,1])
}
\keyword{misc}

\eof
\name{applycalib.calibspline}
\alias{applycalib.calibspline}
\title{ External Calbiration}
\description{ Applys object of class calibspline to massvector or massvectorlist to correct for measurment errors. }
\usage{\method{applycalib}{calibspline}(object,mv,...)}
\arguments{
\item{...}{}
\item{mv}{}
\item{object}{ massvector}
}
\details{ In case of \bold{external calibration} some sample spots are only dedicated  to calibration. Calibration samples which produces equidistant  peaks, which exact masses are known, can be used to precisely  estimate the mass dependent error function. }
\value{
\item{ massvector }{ calibrated massvector}
}
\references{\item{-}{ Gobom J, Mueller M, Egelhofer V, Theiss D, Lehrach H, Nordhoff E, 2002. A calibration method that simplifies and improves accurate determination of peptide molecular masses by MALDI-TOF MS. Anal Chem. 74(15):3915-23.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyextcalib.massvectorlist}},
\code{\link{getextcalib.massvector}},
\code{\link{getextcalib.massvectorlist}},
}
\examples{
 data(mv1)
 data(ppg)
 res<- getextcalib(ppg,getPPGmasses(),error=150)
 plot(res)
 mv2<-applycalib(res,mv1)
 compare(mv1,mv2,error=300)
 rm(mv1,mv2)
 data(mvl)
 mvl<-mvl[1:100]
 res<-applycalib(res,mvl)
}
\keyword{misc}

\eof
\name{applyextcalib.massvector}
\alias{applyextcalib.massvector}
\title{ External Calbiration}
\description{ Applys object of class calibspline to massvector to correct ofr measurment errors.  The error model stored in the calibspline are obtained by the function \code{getextcalib} }
\usage{\method{applyextcalib}{massvector}(object,cS,...)}
\arguments{
\item{...}{}
\item{cS}{ calibspline}
\item{object}{ massvector}
}
\details{ In case of \bold{external calibration} some sample spots are only dedicated  to calibration. Calibration samples which produces equidistant  peaks, which exact masses are known, can be used to precisely  estimate the mass dependent error function. }
\value{
\item{ massvector }{ calibrated massvector}
}
\references{\item{-}{ Gobom J, Mueller M, Egelhofer V, Theiss D, Lehrach H, Nordhoff E, 2002. A calibration method that simplifies and improves accurate determination of peptide molecular masses by MALDI-TOF MS. \emph{Anal Chem.} 74(15):3915-23.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyextcalib.massvectorlist}},
\code{\link{applycalib.calibspline}},
\code{\link{getextcalib.massvector}},
\code{\link{getextcalib.massvectorlist}},
}
\examples{
 data(ppg)
 data(mv1)
 res<-getextcalib(ppg[[1]],getPPGmasses(),error=200)
 mv2<-applyextcalib(mv1,res)
 compare(mv1,mv2)
}
\keyword{misc}

\eof
\name{applyextcalib.massvectorlist}
\alias{applyextcalib.massvectorlist}
\title{ External Calbiration}
\description{ Corrects the massvectorlist for the measurment error stored calibspline object. }
\usage{\method{applyextcalib}{massvectorlist}(object,cS,...)}
\arguments{
\item{...}{ further parameters}
\item{cS}{ object of class calibspline}
\item{object}{ massvectorlist}
}
\details{ In case of external calibration some sample spots are only dedicated  to calibration. Calibration samples which produces equidistant  peaks, which exact masses are known, can be used to precisely  estimate the mass dependent error function. }
\value{
\item{ massvectorlist }{ calibrated massvectorlist}
}
\references{\item{-}{ Gobom J, Mueller M, Egelhofer V, Theiss D, Lehrach H, Nordhoff E, 2002. A calibration method that simplifies and improves accurate determination of peptide molecular masses by MALDI-TOF MS. Anal Chem. 74(15):3915-23.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyextcalib.massvector}},
\code{\link{applyextcalib.massvectorlist}},
\code{\link{getextcalib.massvector}},
\code{\link{getextcalib.massvectorlist}},
}
\examples{
 data(ppg)
 data(mvl)
 res <- getextcalib(ppg,getPPGmasses(),error=150)
 mvl2 <- applyextcalib(mvl,res)
}
\keyword{misc}

\eof
\name{applyintcalib.massvector}
\alias{applyintcalib.massvector}
\title{ Internal Calibration}
\description{ Corrects the massvector for the error model stored in calibintstat object. }
\usage{\method{applyintcalib}{massvector}(object,cal,...)}
\arguments{
\item{...}{ further parameters.}
\item{cal}{ object of class calibintstat}
\item{object}{ massvector}
}
\details{ \bold{Internal calibration} aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ massvector }{ calibrated massvector. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applycalib.calibintstat}},
\code{\link{getintcalib.massvector}},
\code{\link{correctinternal.massvector}},
}
\examples{
 data(mv1)
 data(cal)
 res<-getintcalib(mv1,cal,error=300)
 mv2<- applyintcalib(mv1,res)
 plot(mv1[,1],mv2[,1]-mv1[,1])
}
\keyword{misc}

\eof
\name{applyintcalib.massvectorlist}
\alias{applyintcalib.massvectorlist}
\title{ Internal Calibration}
\description{ Corrects the massvectors in the list for the error model stored in calibintstat object. }
\usage{\method{applyintcalib}{massvectorlist}(object,calc,...)}
\arguments{
\item{...}{ further params}
\item{calc}{ caliblist with objects of class calibintstat}
\item{object}{ massvectorlist}
}
\details{ Internal calibration aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ massvectorlist }{ calibrated massvectorlist. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyintcalib.massvector}},
\code{\link{getintcalib.massvectorlist}},
\code{\link{correctinternal.massvectorlist}},
\code{\link{calibintstat}},
\code{\link{caliblist}},
}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 data(cal)
 res <- getintcalib(mvl,cal,error=300,ppm=FALSE)
 mvl2<-applyintcalib(mvl,res)
}
\keyword{misc}

\eof
\name{applyrecalib.massvector}
\alias{applyrecalib.massvector}
\title{ Precalibration}
\description{ Uses the model of the measurment error stored in a calibrestat object  to correct the masses in the massvector. }
\usage{\method{applyrecalib}{massvector}(object,calc,...)}
\arguments{
\item{...}{ further arguments.}
\item{calc}{ object calibrestat class.}
\item{object}{ massvector.}
}
\details{ \bold{Precalibration} method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the massesvector can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting.\emph{Proteomics.} 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getrecalib.massvector}},
\code{\link{getrecalib.massvectorlist}},
\code{\link{recalibrate.massvector}},
\code{\link{recalibrate.massvectorlist}},
\code{\link{calibrestat}},
\code{\link{calibrelist}},
}
\examples{
 data(mv1)
 res <- getrecalib(mv1)
 plot(res)
 mv2<-applyrecalib(mv1,res)
 compare(mv1,mv2)
}
\keyword{misc}

\eof
\name{applyrecalib.massvectorlist}
\alias{applyrecalib.massvectorlist}
\title{ Recalibration}
\description{ Corrects the massvector for model of the measurment error stored in the calibrestat object. }
\usage{\method{applyrecalib}{massvectorlist}(object,calc,...)}
\arguments{
\item{...}{ further parameters.}
\item{calc}{ caliblist with objects of class calibretstat.}
\item{object}{ massvectorlist.}
}
\details{ Precalibration method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the massesvector can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\value{
\item{ massvectorlist }{ calibrated massvectorlist. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{recalibrate.massvectorlist}},
\code{\link{getrecalib.massvectorlist}},
\code{\link{correctinternal.massvectorlist}},
}
\examples{
 data(mvl)
 res<-getrecalib(mvl)
 summary(res)
 mvl2<-applyrecalib(mvl,res)
}
\keyword{misc}

\eof
\name{as.data.frame.mlist}
\alias{as.data.frame.mlist}
\title{ Data Frames}
\description{ Turns the mlist object into a data.frame }
\usage{\method{as.data.frame}{mlist}(x,row.names=NULL,optional = FALSE)}
\arguments{
\item{optional}{}
\item{row.names}{}
\item{x}{ object of class massvectorlist}
}
\details{ These functions create a data frame, tightly coupled  collections of variables which share many of the properties of  matrices and of lists, used as the fundamental data structure by  most of R's modeling software. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{as.matrix.mlist}},
\code{\link{as.matrix}},
}
\examples{
 data(mvl)
 tmp <- as.data.frame(mvl)
 names(mvl)
 plot(tmp$lengthmv,tmp$mass.Min.)
 data(mvl)
 mvl<-mvl[1:100]
 data(cal)
 test<-getintcalib(mvl,cal,error=500)
 tmp<-as.data.frame(test)
 names(tmp)
}
\keyword{misc}

\eof
\name{as.list.massvectorlist}
\alias{as.list.massvectorlist}
\title{ List}
\description{ Turns the massvectorlist into a list }
\usage{\method{as.list}{massvectorlist}(x,...)}
\arguments{
\item{...}{ further parameter.}
\item{x}{ massvectorlist.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 res<-as.list(mvl)
 class(res)
}
\keyword{misc}

\eof
\name{as.lm.calibintstat}
\alias{as.lm.calibintstat}
\title{ Fitting Linear Models}
\description{ attempts to coerce its argument into a linear model. }
\usage{\method{as.lm}{calibintstat}(object,...)}
\arguments{
\item{...}{}
\item{object}{}
}
\value{
\item{ object of class "lm".}{}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{as.matrix.massvector}
\alias{as.matrix.massvector}
\title{ Matrices}
\description{ Turns the massvector into a matrix }
\usage{\method{as.matrix}{massvector}(x)}
\arguments{
\item{x}{ massvector}
}
\value{
\item{ matrix }{ matrix with masses and intensities.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{peaks.massvector}},
}
\examples{
 data(mv1)
 res<-as.matrix(mv1)
 class(res)
}
\keyword{misc}

\eof
\name{as.matrix.mlist}
\alias{as.matrix.mlist}
\title{ Matrices}
\description{ Turns the caliblist into a matrix }
\usage{\method{as.matrix}{mlist}(x)}
\arguments{
\item{x}{ caliblist}
}
\value{
\item{ matrix }{ matrix}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{as.data.frame.mlist}},
}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 data(cal)
 test<-getintcalib(mvl,cal,error=500)
 tmp<-as.matrix(test)
 colnames(tmp)
 dim(tmp)
 data(mvl)
 tmp<-as.matrix(mvl)
 print(colnames(mvl))
 plot(tmp[,"lengthmv"],tmp[,"mass.Min."])
}
\keyword{misc}

\eof
\name{as.vector.calibintstat}
\alias{as.vector.calibintstat}
\title{ Coerces to vectors}
\description{ 'as.vector', a generic, attempts to coerce its argument into a   vector of mode 'mode' (the default is to coerce to whichever mode  is most convenient).  The attributes of 'x' are removed. }
\usage{\method{as.vector}{calibintstat}(x,mode="any")}
\arguments{
\item{mode}{ any}
\item{x}{ object of class calibintstat}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 data(cal)
 res<-getintcalib(mv1,cal,error=500,ppm=TRUE)
 as.vector(res)
}
\keyword{misc}

\eof
\name{as.vector.calibrestat}
\alias{as.vector.calibrestat}
\title{ Coerces to vector}
\description{ coerces the calibrestat object into a vector. }
\usage{\method{as.vector}{calibrestat}(x,...)}
\arguments{
\item{...}{}
\item{x}{ calibrestat}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 res<-getrecalib(mv1)
 as.vector(res)
}
\keyword{misc}

\eof
\name{as.vector.massvector}
\alias{as.vector.massvector}
\title{ Vector}
\description{ Casts massvector into vector. It does it by calling the summary.massvector method first and unlisting the result. }
\usage{\method{as.vector}{massvector}(x, mode="any")}
\arguments{
\item{mode}{}
\item{x}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 as.vector(mv1)
}
\keyword{misc}

\eof
\name{c.massvector}
\alias{c.massvector}
\title{ Combine Massvectors into one Massvector.}
\description{ Combines Massvectors into one Massvector. }
\usage{\method{c}{massvector}(x,...)}
\arguments{
\item{...}{ massvectors to be concatenated.}
\item{x}{ massvector}
}
\value{
\item{ massvector }{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{rbind}},
}
\examples{
 data(mv1)
 data(mv2)
 par(mfrow=c(2,1))
 plot(mv1)
 plot(mv2,add=TRUE)
 plot(c(mv1,mv2))
}
\keyword{misc}

\eof
\name{c.massvectorlist}
\alias{c.massvectorlist}
\title{ Combine }
\description{ Combines Massvectorlist into one Massvectorlist. }
\usage{\method{c}{massvectorlist}(mvl,...)}
\arguments{
\item{...}{ massvectorlists to be concatenated.}
\item{mvl}{ massvector}
}
\details{ It does not check if the massvectors in the list are unique. }
\value{
\item{ massvectorlist }{ massvectorlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{c}},
}
\examples{
 data(mvl)
 mvl2<-c(mvl[1:100],mvl[1:50])
 mvl2
}
\keyword{misc}

\eof
\name{cal}
\docType{data}                     
\alias{cal}
\title{Calibration masses}
\usage{data(cal)} 
\description{A massvector with calibration masses. (mainly trypsin autoproteolysis peaks)}                                
\author{Witold E. Wolski}         
\keyword{datasets}     

\eof
\name{calibexternal.massvector}
\alias{calibexternal.massvector}
\title{ External Calbiration}
\description{ Perfroms external calibration. Obtains the error model by calling \code{getextcalib}  and corrects the masses in the massvector for the errror. }
\usage{\method{calibexternal}{massvector}(object,ppg,calib,...)}
\arguments{
\item{...}{ further parameters.}
\item{calib}{ a massvector with exact masses of the calibration sample (ppg).}
\item{object}{ massvector}
\item{ppg}{ either a massvector or massvectorlist with masses of the calibration sample (e.g. poly-(propylene glycol)).}
}
\details{ In case of \bold{external calibration} some sample spots are only dedicated  to calibration. Calibration samples which produces equidistant  peaks, which exact masses are known, can be used to precisely  estimate the mass dependent error function. }
\value{
\item{ massvector}{ calibrated massvector}
}
\references{\item{-}{ Gobom J, Mueller M, Egelhofer V, Theiss D, Lehrach H, Nordhoff E, 2002. A calibration method that simplifies and improves accurate determination of peptide molecular masses by MALDI-TOF MS.\emph{Anal Chem.} 74(15):3915-23.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyextcalib.massvectorlist}},
\code{\link{getextcalib.massvector}},
\code{\link{getextcalib.massvectorlist}},
\code{\link{calibexternal.massvector}},
\code{\link{applycalib.calibspline}},
}
\examples{
 data(ppg)
 data(mv1)
 mv2<-calibexternal(mv1,ppg)
 compare(mv1,mv2)
}
\keyword{misc}

\eof
\name{calibexternal.massvectorlist}
\alias{calibexternal.massvectorlist}
\title{ External Calbiration}
\description{ Perfroms external calibration of massvectorlist. Obtains the model of the measurment error by \code{getextcalib} and corrects the masses for this error. }
\usage{\method{calibexternal}{massvectorlist}(object,ppg,calib,error=300,...)}
\arguments{
\item{...}{ further parameters.}
\item{calib}{ a massvector with exact masses for the massvectors of the calibration samples (ppg).}
\item{error}{ relative error of the measurment in (ppm).}
\item{object}{ massvectorlist}
\item{ppg}{ either a massvector or massvectorlist with masses of the calibration sample (e.g poly-(propylene glycol) ppg)}
}
\details{ In case of external calibration some sample spots are only dedicated  to calibration. Calibration samples which produces equidistant  peaks, which exact masses are known, can be used to precisely  estimate the mass dependent error function. }
\value{
\item{ massvectorlist}{ calibrated massvector}
}
\references{\item{-}{ Gobom J, Mueller M, Egelhofer V, Theiss D, Lehrach H, Nordhoff E, 2002. A calibration method that simplifies and improves accurate determination of peptide molecular masses by MALDI-TOF MS. Anal Chem. 74(15):3915-23.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{calibexternal.massvector}},
\code{\link{applyextcalib.massvectorlist}},
\code{\link{getextcalib.massvector}},
\code{\link{getextcalib.massvectorlist}},
\code{\link{calibexternal.massvector}},
\code{\link{applycalib.calibspline}},
}
\examples{
 data(mvl)
 data(ppg)
 res <- calibexternal(mvl,ppg,getPPGmasses(),error=150)
}
\keyword{misc}

\eof
\name{calibintstat}
\alias{calibintstat}
\title{ Constructor}
\description{ Returns an object of class calibintstat. Is used by function \code{getintcalib}. }
\usage{calibintstat(info , lm , ...)}
\arguments{
\item{...}{ further parameters Coef.Intercept, Coef.Slope, lengthmv, nrmatch, error.mean, error.stdv, ppm.}
\item{info}{ identifier of the calibstat object. Links it with the massvector.}
\item{lm}{ object of class 'lm' (linear model)}
}
\value{
\item{ calibintstat }{ object of class calibintstat.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link[base]{lm}},
}
\examples{
 data(mv1)
 data(cal)
 res<-getintcalib(mv1,cal,error=2,ppm=FALSE)
 class(res)
 plot(res)
 res<-getintcalib(mv1,cal,error=400,ppm=TRUE)
 class(res)
 plot(res)
}
\keyword{misc}

\eof
\name{caliblist}
\alias{caliblist}
\alias{calibrelist},
\alias{calibintlist},
\title{ Constructor}
\description{ Returns object of class caliblist. }
\usage{caliblist(class,experiment,data,...)}
\arguments{
\item{...}{}
\item{class}{ string with class name "calibrestat","calibintstat".}
\item{data}{ a list with calibstat objects}
\item{experiment}{ string with experiment name.}
}
\details{ Returns objects of class calibrelist and calibintlist. The name of the class  have to be specified as the first argument in the constructor.  Constructor is used by function getrecalib.massvectorlist & getintcalib.massvectorlist }
\value{
\item{ calibrelist }{ If called with first (\code{class}) argument set to "calibrelist".}
\item{ calibintlist }{ If called with first (\code{class}) argument set to "calibintlist".}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getrecalib.massvectorlist}},
\code{\link{getintcalib.massvectorlist}},
}
\examples{
 #Example calibrelist class:
 data(mvl)
 mvl<-mvl[1:10]
 res <- getrecalib(mvl)
 print(res)
 summary(res)
 image(res,what="Coef.Intercept")
 image(res,what="Coef.Slope")
 plot(res)
 hist(res)
 dres<-as.data.frame(res)
 plot(dres$Coef.Intercept,dres$PQM,xlab="Coef.Intercept",ylab="PQM")
 #greate subset.
 res2<-subset(res,PQM>10)
 length(res2)
 plot(res2)
 test<-applyrecalib(mvl, res2)
}
\keyword{misc}

\eof
\name{calibrestat}
\alias{calibrestat}
\title{ Constructor}
\description{ Returns object of class calibrestat. Used by function \code{getrecalib.massvector}.  A calibrestat object is returned by the \code{getrecalib.massvector} method. }
\usage{calibrestat(info,...)}
\arguments{
\item{...}{ can be Coeff.Intercept,Coeff.Slope,lengthvm,PQM,tcoor.}
\item{info}{ unique identifier.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getrecalib.massvector}},
}
\examples{
 data(mv1)
 res <- getrecalib(mv1)
 print(res)
 as.vector(res)
 summary(res)
 image(res)
 plot(res)
}
\keyword{misc}

\eof
\name{calibspline}
\alias{calibspline}
\title{ Constructor}
\description{ Returns object of class calibspline. It is used by the function \code{getextcalib.massvector}. }
\usage{calibspline(ispl,mv,error,theo)}
\arguments{
\item{error}{ vector with errors.}
\item{ispl}{ object of class "smooth.spline"}
\item{mv}{ massvector}
\item{theo}{ vector with theoretical masses}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getextcalib.massvector}},
}
\keyword{misc}

\eof
\name{compare.massvector}
\alias{compare.massvector}
\title{ Compares massvectors}
\description{ Compares the masses in the massvectors. Returns basic statistics about the matching peaks.  Plots the relative or absolute error of matchin peaks. }
\usage{\method{compare}{massvector}(object,mv2,plot=TRUE,error=1000,ppm=TRUE,uniq=FALSE,...)}
\arguments{
\item{...}{ further parameters.}
\item{error}{ size of the measurment error (default 150 ppm)}
\item{mv2}{ massvector}
\item{object}{ massvector}
\item{plot}{ True - plot the relatvetor absolute error. \code{FALSE} - no plotting.}
\item{ppm}{ \code{TRUE} - relative error in parts per million, \code{FALSE} - absolute error.}
\item{uniq}{ logical }
}
\value{
\item{ FMSTAT }{ Fowlkes & Mallows statistik (nr matching)/sqrt(length(object)*length(mv2))}
\item{ min }{ smallest error}
\item{ ... }{ 1st qu. , mean, median, 3rd qu., max and stdv of error.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{resid}},
}
\examples{
 data(mv1)
 data(mv2)
 compare(mv1,mv2,error=5000,ppm=TRUE,uniq=TRUE)
 compare(mv2,mv1,error=1,ppm=FALSE,uniq=TRUE)
}
\keyword{misc}

\eof
\name{correctinternal.massvector}
\alias{correctinternal.massvector}
\title{ Internal Calibration}
\description{ Corrects the masses of the massvector. It first obtains the model of the  measrument error by calling \code{getintcalib.massvector}. It than corrects the masses  by a call to \code{applyintcalib.massvector}. }
\usage{\method{correctinternal}{massvector}(object,calib,error=500,uniq=FALSE,ppm=TRUE,...)}
\arguments{
\item{...}{}
\item{calib}{ massvector with calibration masses}
\item{error}{}
\item{object}{ massvector}
\item{ppm}{}
\item{uniq}{}
}
\details{ \bold{Internal calibration} aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ massvector }{ calibrated massvector. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getintcalib.massvector}},
\code{\link{calibintstat}},
\code{\link{applycalib.calibintstat}},
}
\examples{
 data(mv1)
 data(cal)
 res <- correctinternal(mv1,cal,error=200)
}
\keyword{misc}

\eof
\name{correctinternal.massvectorlist}
\alias{correctinternal.massvectorlist}
\title{ Internal Calibration}
\description{ Determines the measurment error of the masses using \code{getintcalib.massvectorlist}.  It refines the error model and applies it to the massvector by \code{applyintcalib.massvectorlist}. }
\usage{\method{correctinternal}{massvectorlist}(object,calib,error=500,ppm=TRUE,...)}
\arguments{
\item{...}{}
\item{calib}{ massvector with calibration masses}
\item{error}{ assumed measurment error.}
\item{object}{ massvectorlist}
\item{ppm}{ logical;\code{TRUE}- describe the error as relative error. \code{FALSE}- describe the error as absolute error.}
}
\details{ \bold{Internal calibration} aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ massvectorlist }{ calibrated massvectorlist. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getintcalib.massvectorlist}},
\code{\link{correctinternal.massvector}},
\code{\link{getintcalib.massvector}},
\code{\link{calibintstat}},
\code{\link{caliblist}},
}
\examples{
 data(mvl)
 data(cal)
 mvl2 <- correctinternal( mvl,cal, error=500 , ppm=TRUE )
}
\keyword{misc}

\eof
\name{diffFilter.massvector}
\alias{diffFilter.massvector}
\title{ Abundant Differences}
\description{ Removes mass differences from the massvector. }
\usage{\method{diffFilter}{massvector}(object,listofdiffs,higher=TRUE,error=0.05,uniq=TRUE,prune=TRUE,...)}
\arguments{
\item{...}{ further parameters.}
\item{error}{ How much the differences can diviate from the differences given in listofdiffs.}
\item{higher}{ logical;\code{TRUE} - remove higher mass, \code{FALSE} = remove lower mass.}
\item{listofdiffs}{}
\item{object}{ massvector}
\item{prune}{ logical;\code{TRUE} - remove mass, \code{FALSE} = return modified mass.}
\item{uniq}{}
}
\details{ Removes one of the masses contributing to a mass difference given in the list of differences.  Can be used if a variable modification are present in the massvector but can not be considered by the identification software. It also can be used to return the modified masses. }
\value{
\item{ massvector }{ filtered massvector.}
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getdiff.massvector}},
\code{\link{getdiff.massvectorlist}},
\code{\link{diffFilter.massvectorlist}},
}
\examples{
 data(mv1)
 res<-getdiff(mv1,range=c(0,100))
 diffFilter(mv1,res,higher=TRUE)
 diffFilter(mv1,res,higher=FALSE)
}
\keyword{misc}

\eof
\name{diffFilter.massvectorlist}
\alias{diffFilter.massvectorlist}
\title{ Abundant Differences}
\description{ Removes masses from the massvector. }
\usage{\method{diffFilter}{massvectorlist}(object,listofdiffs,higher=TRUE,error=0.05,uniq=TRUE,prune=FALSE,...)}
\arguments{
\item{...}{}
\item{error}{ How much the differences can diviate from the differences given in listofdiffs}
\item{higher}{ \code{TRUE} - remove higher mass, \code{FALSE} = remove lower mass.}
\item{listofdiffs}{}
\item{object}{}
\item{prune}{ logical;default = \code{TRUE} - removes modified mass; \code{FALSE} - return modified mass.}
\item{uniq}{}
}
\details{ Removes one of the masses contributing to a mass difference given in the list of diffs.  Can be used if a variable modification are present in the massvector but can not be considered by the identification software.  Abundant intra massvector mass differences indicate the  presence of variable modifications in the data set. This  information can be used to optimize the search strategy. }
\value{
\item{ massvector }{ filtered massvector.}
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{diffFilter.massvector}},
\code{\link{getdiff.massvector}},
\code{\link{getdiff.massvectorlist}},
}
\examples{
 data(mvl)
 res<-getdiff(mvl,range=c(0,100))
 hist(res)
 res<-gamasses(res,abund=100)
 test<-diffFilter(mvl,res,higher=TRUE,error=0.1,uniq=TRUE)
 test
}
\keyword{misc}

\eof
\name{experiment.mlist}
\alias{experiment.mlist}
\alias{info.mlist},
\title{ Info Acces}
\description{ Access to the experiment field of the mlist. Can be used for setting or getting the experiment field. }
\usage{\method{experiment}{mlist}(object,experiment,...)}
\arguments{
\item{...}{}
\item{experiment}{ New experiment name. If not missing function returns massvector with new info field content.}
\item{object}{ object of class mlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 experiment(mvl)
 mvl<-experiment(mvl,"newname")
}
\keyword{misc}

\eof
\name{gamasses.massvector}
\alias{gamasses.massvector}
\title{ Abundant masses}
\description{ Determines abundant masses in a massvector. }
\usage{\method{gamasses}{massvector}(object,accur = 0.1,abund = 50,...)}
\arguments{
\item{...}{ further parameters.}
\item{abund}{ how many times a mass have to occur in a mass bin to be considered as an abundant mass.}
\item{accur}{ measurment accuracy in m/z}
\item{object}{ massvector}
}
\details{ Abundant masses are masses that occur in a large  fraction of the massvectors. Typical abundant mass  are derived from tryptic autoproteolysis products.  Abundant masses can also often be assigned to keratin  isoforms (human hair- and skin proteins).  Many of the abundant masses cannot be assigned to any protein.  Abundant masses can be used for calibration.  Removing them may increase the identification specificity. }
\value{
\item{ massvector }{ massvector with abundant masses.}
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{gamasses.massvectorlist}},
}
\examples{
 data(mvl)
 mv<-unlist(mvl) 
 res<-gamasses(mv,abund=30,accur=0.3)
 plot(res)
}
\keyword{misc}

\eof
\name{gamasses.massvectorlist}
\alias{gamasses.massvectorlist}
\title{ Abundant masses}
\description{ Determines abundant masses in a massvector. }
\usage{\method{gamasses}{massvectorlist}(object,accur=0.1,abund=50,...)}
\arguments{
\item{...}{}
\item{abund}{ how many times a mass have to occur to be an abundant mass.}
\item{accur}{ measurment accuracy}
\item{object}{ massvectorlist}
}
\details{ Abundant masses are masses that occur in a large  fraction of the massvectors. Typical abundant mass  are derived from tryptic autoproteolysis products.  Abundant masses can also often be assigned to keratin  isoforms (human hair- and skin proteins).  Many of the abundant masses cannot be assigned to any protein.  Abundant masses can be used for calibration.  Removing them may increase the identification specificity. }
\value{
\item{ massvector }{ massvector with abundant masses.}
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{gamasses.massvector}},
}
\examples{
 data(mvl)
 #Filtering for abundant masses.
 res<-gamasses(mvl,abund=50)
 plot(res)
 mvFilter(mvl[[1]],res)
 res2<-mvFilter(mvl,res,abundant=TRUE)
 image(res2,what="lengthmv")
 image(mvl,what="lengthmv")
 image(image(res2,what="lengthmv")/image(mvl,what="lengthmv"))
 
 hist(mvl,accur=0.3)
 hist(res2,add=TRUE,col=2,accur=0.3)
}
\keyword{misc}

\eof
\name{getPPGmasses}
\alias{getPPGmasses}
\title{ PPG masses}
\description{ Computes poly-(propylene glycol) masses. }
\usage{getPPGmasses(start=10,end=100)}
\arguments{
\item{end}{ length of longest polymer.}
\item{start}{ length of shortest polymer.}
}
\value{
\item{ massvector }{ massvector of ppg masses}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 plot(getPPGmasses(start=12,end=100))
}
\keyword{misc}

\eof
\name{getaccC}
\alias{getaccC}
\title{ Find Matching Masses}
\description{ Returns the indices of masses matching to each other. }
\usage{getaccC(pl,cal,error=500,ppm=TRUE,uniq=FALSE)}
\arguments{
\item{cal}{ vector with masses}
\item{error}{ error in Da or ppm.}
\item{pl}{ vector with masses}
\item{ppm}{ \code{TRUE} - then error has to be given as relative error in ppm. \code{FALSE} - error are absolute error in dalton.}
\item{uniq}{ \code{TRUE} - return only closest match to mass in cal. \code{FALSE} - return all matches in the error range.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 getaccC(1001:1010,1001:1010,error=300,ppm=TRUE,uniq=TRUE)
}
\keyword{misc}

\eof
\name{getdiff.massvector}
\alias{getdiff.massvector}
\title{ Massdifferences}
\description{ Computes mass differences in the object. }
\usage{\method{getdiff}{massvector}(object,range=c(0,100),...)}
\arguments{
\item{...}{}
\item{object}{ massvector}
\item{range}{}
}
\details{ Removes one of the masses contributing to a mass difference given in the list of diffs.  Can be used if a variable modification are present in the massvector but can not be considered by the identification software. }
\value{
\item{ massvector }{ filtered massvector.}
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{getdiff.massvectorlist}
\alias{getdiff.massvectorlist}
\title{ Massdifferences}
\description{ Computes mass differences in the mv. }
\usage{\method{getdiff}{massvectorlist}(object,masst="massrea",range=c(0,100),...)}
\arguments{
\item{...}{}
\item{masst}{}
\item{object}{}
\item{range}{}
}
\details{ Removes one of the masses contributing to a mass difference given in the list of diffs.  Can be used if a variable modification are present in the massvector but can not be considered by the identification software.  Abundant intra massvector mass differences indicate the  presence of variable modifications in the data set. This  information can be used to optimize the search strategy. }
\value{
\item{ massvector }{ filtered massvector.}
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getdiff.massvector}},
}
\examples{
 data(mvl)
 res<-getdiff(mvl,range=c(0,100))
 plot(res)
 tt<-gamasses(res,abund=40)
 plot(tt)
}
\keyword{misc}

\eof
\name{getextcalib.massvector}
\alias{getextcalib.massvector}
\title{ External Error Model}
\description{ Returns the error model obtained from the calibration sample. }
\usage{\method{getextcalib}{massvector}(object,calib,error=300,...)}
\arguments{
\item{...}{}
\item{calib}{ massvector with calibration masses}
\item{error}{ relative measurment error in ppm.}
\item{object}{ massvector}
}
\details{ In case of \bold{external calibration} some sample spots are only dedicated  to calibration. Calibration samples which produces equidistant  peaks, which exact masses are known, can be used to precisely  estimate the mass dependent error function. }
\value{
\item{ calibspline }{ can be used to calibrate peaklists}
}
\references{\item{-}{ Gobom J, Mueller M, Egelhofer V, Theiss D, Lehrach H, Nordhoff E, 2002. A calibration method that simplifies and improves accurate determination of peptide molecular masses by MALDI-TOF MS. \emph{Anal Chem.} 74(15):3915-23.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{calibspline}},
\code{\link{applyextcalib.massvector}},
}
\examples{
 data(mv1)
 data(ppg)
 res<-getextcalib(ppg[[1]])
 mv2 <- applycalib(res,mv1)
 plot(mv1[,1],mv2[,1]-mv1[,1])
}
\keyword{misc}

\eof
\name{getextcalib.massvectorlist}
\alias{getextcalib.massvectorlist}
\title{ External Error Model}
\description{ Returns the error model obtained from the calibration sample. }
\usage{\method{getextcalib}{massvectorlist}(object,calib,error=250,...)}
\arguments{
\item{...}{ further parameters.}
\item{calib}{ massvector with calibration masses (ppg)}
\item{error}{ relative measurment error in ppm. (peaks in this range are assumed as matching)}
\item{object}{ massvectorlist with calibration sample (ppg) masses}
}
\value{
\item{ calibspline }{ can be used to calibrate peaklists}
}
\references{\item{-}{ Gobom J, Mueller M, Egelhofer V, Theiss D, Lehrach H, Nordhoff E, 2002. A calibration method that simplifies and improves accurate determination of peptide molecular masses by MALDI-TOF MS. Anal Chem. 74(15):3915-23.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{calibspline}},
\code{\link{applyextcalib.massvectorlist}},
\code{\link{getextcalib.massvector}},
}
\keyword{misc}

\eof
\name{getglobalcalib.massvectorlist}
\alias{getglobalcalib.massvectorlist}
\title{ Set Based Internal Calbiration}
\description{ Obtains error model using massvector with known masses. }
\usage{\method{getglobalcalib}{massvectorlist}(object , calib , error=500,ppm=TRUE, labund=12, abund = length(object)/5 , accur = ifelse(ppm,error/2000,error) ,...)}
\arguments{
\item{...}{ further parameters.}
\item{abund}{ default =  length(object)/5}
\item{accur}{ default =  ifelse(ppm,error,error/2000)}
\item{calib}{ massvector with calibration masses}
\item{error}{ assumed measurment error.}
\item{labund}{ how many abundant masses to use for calibration. default=12.}
\item{object}{ massvectorlist}
\item{ppm}{ logical; \code{TRUE}- describe the error as relative error. \code{FALSE}- describe the error as absolute error.}
}
\details{ Set based Calibration copes with the problem of missing calibration  masses. It first extracts about 15 most abundant masses of the  massvectorlist, then they are internally calibrated and used  as new calibration masses. In this fashion more massvectors  can be internally calibrated.  Internal calibration aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ calibintstat }{ object of class calibintstat. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyintcalib.massvector}},
\code{\link{getintcalib.massvector}},
\code{\link{correctinternal.massvectorlist}},
\code{\link{calibintstat}},
\code{\link{caliblist}},
}
\examples{
 data(mvl)
 data(cal)
 res<-getglobalcalib(mvl,cal,error=500,ppm=TRUE)
 hist(res)
}
\keyword{misc}

\eof
\name{getintcalib.massvector}
\alias{getintcalib.massvector}
\title{ Internal Calbiration.}
\description{ Obtains error model by alingning masses in massvector to known masses (calibration list). }
\usage{\method{getintcalib}{massvector}(object,calib,error=500,uniq=FALSE,ppm=TRUE,...)}
\arguments{
\item{...}{}
\item{calib}{ massvector with calibration masses}
\item{error}{ assumed measurment error.}
\item{object}{ massvector}
\item{ppm}{ \code{TRUE}- describe the error as relative error. \code{FALSE}- describe the error as absolute error.}
\item{uniq}{ \code{TRUE}- use only mass closest to calibration mass. \code{FALSE}- use all masses closer to the calibration mass then given error.}
}
\details{ \bold{Internal calibration} aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found.   }
\value{
\item{ calibintstat }{ object of class calibintstat.}
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyintcalib.massvector}},
\code{\link{getintcalib.massvector}},
\code{\link{correctinternal.massvectorlist}},
\code{\link{calibintstat}},
}
\keyword{misc}

\eof
\name{getintcalib.massvectorlist}
\alias{getintcalib.massvectorlist}
\title{ Internal Calbiration}
\description{ Obtains error model using massvector with known masses. }
\usage{\method{getintcalib}{massvectorlist}(object,calib,error=500,ppm=TRUE, ... )}
\arguments{
\item{...}{}
\item{calib}{ massvector with calibration masses}
\item{error}{ assumed measurment error.}
\item{object}{ massvectorlist}
\item{ppm}{ \code{TRUE}- describe the error as relative error. \code{FALSE}- describe the error as absolute error.}
}
\details{ Internal calibration aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ calibintstat }{ object of class calibintstat. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyintcalib.massvector}},
\code{\link{getintcalib.massvector}},
\code{\link{correctinternal.massvectorlist}},
\code{\link{calibintstat}},
\code{\link{caliblist}},
}
\examples{
 data(mvl)
 data(cal)
 res<-getintcalib(mvl,cal,error=400,ppm=TRUE)
 plot(res)
}
\keyword{misc}

\eof
\name{getrecalib.massvector}
\alias{getrecalib.massvector}
\title{ Precalibration}
\description{ Obtains the an error model using the wavelength analysis of the peaklist. }
\usage{\method{getrecalib}{massvector}(object,plot=FALSE,...)}
\arguments{
\item{...}{}
\item{object}{}
\item{plot}{ \code{TRUE} - A graphic showing the \eqn{F(\omega)}{F(omega)} function. default \code{FALSE}}
}
\details{ \bold{Precalibration} method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the massesvector can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\value{
\item{ calibrestat }{ object of class calibrestat.}
}
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting.\emph{ Proteomics.} 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{applyrecalib.massvector}},
\code{\link{massvector}},
\code{\link{calibrestat}},
\code{\link{wsFilter.massvector}},
}
\examples{
 data(mv1)
 res <- getrecalib(mv1)
 print(res)
 as.vector(res)
 summary(res)
 image(res)
 plot(res)
}
\keyword{misc}

\eof
\name{getrecalib.massvectorlist}
\alias{getrecalib.massvectorlist}
\title{ Precalibration}
\description{ Obtain the error model using the wavelength analysis of the peaklist. }
\usage{\method{getrecalib}{massvectorlist}(object,plot=FALSE,...)}
\arguments{
\item{...}{ further parameters.}
\item{object}{ massvectorlist}
\item{plot}{ logical; \code{TRUE} - A graphic showing the \eqn{F(\omega)}{F(omega)}. default \code{FALSE}}
}
\details{ Precalibration method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the massesvector can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\value{
\item{ caliblist }{ caliblist with objects of class calibrestat.}
}
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. Proteomics. 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getrecalib.massvector}},
\code{\link{applyrecalib.massvector}},
\code{\link{massvector}},
\code{\link{calibrestat}},
\code{\link{wsFilter.massvectorlist}},
}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 res <- getrecalib(mvl)
 print(res)
 summary(res)
 image(res,what="Coef.Intercept")
 image(res,what="Coef.Slope")
 plot(res)
 hist(res)
 dres<-as.data.frame(res)
 plot(dres$Coef.Intercept,dres$PQM,xlab="Coef.Intercept",ylab="PQM")
 #create subset.
 res2<-subset(res,PQM>10)
 length(res2)
 plot(res2)
 test<-applyrecalib(mvl, res2)
 plot(test)
}
\keyword{misc}

\eof
\name{globalcalib.massvectorlist}
\alias{globalcalib.massvectorlist}
\title{ Set Based Internal Calibration}
\description{ Determines the error and corrects for it. }
\usage{\method{globalcalib}{massvectorlist}(object , calib , error=500, labund = 12, ppm=TRUE , abund=length(object)/5,accur = ifelse(ppm,error/2000,error) ,...)}
\arguments{
\item{...}{ further parameters.}
\item{abund}{ default  }
\item{accur}{ default }
\item{calib}{ massvector with calibration masses}
\item{error}{ assumed measurment error.}
\item{labund}{ how many abundant masses use for calibration. (8-12 masses are sufficient).}
\item{object}{ massvectorlist}
\item{ppm}{ \code{TRUE}- describe the error as relative error. \code{FALSE}- describe the error as absolute error.}
}
\details{ Set based Calibration copes with the problem of missing calibration  masses. It first extracts about 15 most abundant masses of the  massvectorlist, then they are internally calibrated and used  as new calibration masses. In this fashion more massvectors  can be internally calibrated.  Internal calibration aligns masses of  peaks to known masses and determines by linear regression a affine  function that describing the relative error. The internal  correction fails when no calibration peaks can be found. }
\value{
\item{ massvectorlist }{ calibrated massvectorlist. }
}
\references{\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getintcalib.massvectorlist}},
\code{\link{correctinternal.massvectorlist}},
\code{\link{getintcalib.massvector}},
\code{\link{calibintstat}},
\code{\link{caliblist}},
}
\examples{
 data(mvl)
 data(cal)
 mvl2<-globalcalib(mvl,cal,error=500,labund=12)
}
\keyword{misc}

\eof
\name{hist.calibintlist}
\alias{hist.calibintlist}
\title{ Histogram Plot}
\description{ Computes histograms of the lengthmv, Coef.Intercept, Coef.Slope ... }
\usage{\method{hist}{calibintlist}(x,...)}
\arguments{
\item{...}{ further graphical parameters.}
\item{x}{ calibrelist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 data(cal)
 mvl <- mvl[1:100]
 data(cal)
 ires <- getintcalib(mvl,cal,error=250)
 hist(ires)
}
\keyword{misc}

\eof
\name{hist.calibrelist}
\alias{hist.calibrelist}
\title{ Histogram Plot}
\description{ Computes Histograms of the lengthmv, Coef.Intercept, Coef.Slope, PQM. }
\usage{\method{hist}{calibrelist}(x,...)}
\arguments{
\item{...}{ further graphical parameters.}
\item{x}{ calibrelist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 res2 <- getrecalib(mvl) # get recalibration model for not filtered data
 hist(res2)
}
\keyword{misc}

\eof
\name{hist.calibstat}
\alias{hist.calibstat}
\title{ Histogram}
\description{ Histogram }
\usage{\method{hist}{calibstat}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class calibstat}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{hist.massvector}
\alias{hist.massvector}
\title{ Histograms}
\description{ Histograms }
\usage{\method{hist}{massvector}(x,accur = 0.1,abund = 0, main=info(x) ,xlab="m/z",xlim=c(min(mass(x)),max(mass(x))),add=FALSE,col=1,...)}
\arguments{
\item{...}{ further plotting arguments.}
\item{abund}{ draws a horizontal line at the frequency given by abund.}
\item{accur}{ sets the bin width of the histogramm.}
\item{add}{ T-adds the histogram to an existing image.}
\item{col}{ the color of the histogram.}
\item{main}{}
\item{x}{}
\item{xlab}{ sets the xlabels.}
\item{xlim}{ sets the min and max value to be displayed.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{hist}},
}
\examples{
 data(mv1)
 hist(mv1)
}
\keyword{misc}

\eof
\name{hist.massvectorlist}
\alias{hist.massvectorlist}
\title{ Histograms}
\description{ Histogram of mass frequencies in the massvectorlist. }
\usage{\method{hist}{massvectorlist}(x,accur = 0.1, main=info(mvl) ,xlab="m/z",xlim=c(700,4500),add=FALSE,col=1,...)}
\arguments{
\item{...}{ further parameters.}
\item{accur}{ bin width for plotting mass frequencies.}
\item{add}{ logical; If \code{TRUE} add to already existing plot.}
\item{col}{ color of the histogram,}
\item{main}{ title of graph}
\item{x}{ massvectorlist}
\item{xlab}{ a title for the x axis.}
\item{xlim}{ the range to be encompassed by the x axis.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{hist.massvector}},
}
\examples{
 data(mvl)
 hist(mvl)
}
\keyword{misc}

\eof
\name{hist.mylistobj}
\alias{hist.mylistobj}
\title{ hist}
\description{ hist }
\usage{\method{hist}{mylistobj}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class mylistobj}
}
\details{ mylistobj provides basic functionality for objects implemented using list to store the attributes. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{histLengths}
\alias{histLengths}
\title{ Histograms}
\description{ Histogram of the massvector lengths. }
\usage{histLengths(x,main=info(x),xlab="length of massvectors",...)}
\arguments{
\item{...}{ further parameters.}
\item{main}{ info(x)}
\item{x}{ massvectorlist}
\item{xlab}{ length of massvectors.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link[base]{hist}},
}
\keyword{misc}

\eof
\name{image.massvector}
\alias{image.massvector}
\title{ Display a Color Image}
\description{ Creates a grid of colored or gray-scale rectangles with colors  corresponding to the mass differences within the peaklist  or within two peaklists. }
\usage{\method{image}{massvector}(x,mv2,error=NULL,ppm=FALSE,col=topo.colors(100),...)}
\arguments{
\item{...}{}
\item{col}{ a list of colors such as that generated by `rainbow',`heat.colors', `topo.colors', `terrain.colors' or similar functions.}
\item{error}{ up to which mass difference display the differences.}
\item{mv2}{ massvector}
\item{ppm}{}
\item{x}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{plot.massvector}},
\code{\link{hist.massvector}},
}
\examples{
 data(mv2)
 data(mv1)
 image(mv1,mv2)
 image(mv1,mv2,error=500)
}
\keyword{misc}

\eof
\name{image.mlist}
\alias{image.mlist}
\title{ Display a Color Image}
\description{ Creates a grid of colored or gray-scale rectangles with colors  corresponding to the values in 'z'.  This can be used to display  three-dimensional or spatial data aka "images". This is a generic  function. }
\usage{\method{image}{mlist}(x,what="",col=terrain.colors(100),...)}
\arguments{
\item{...}{}
\item{col}{ a list of colors such as that generated by 'rainbow', 'heat.colors', 'topo.colors', 'terrain.colors' or similar functions.}
\item{what}{ what value to display on the image.}
\item{x}{ object of class mlist. (e.g}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 image(mvl,what="lengthmv")
}
\keyword{misc}

\eof
\name{image.mylistobj}
\alias{image.mylistobj}
\title{ image}
\description{ image }
\usage{\method{image}{mylistobj}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class mylistobj}
}
\details{ mylistobj provides basic functionality for objects implemented using list to store the attributes. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{info.mylistobj}
\alias{info.mylistobj}
\title{ Info Acces}
\description{ access to the info field of the mylistobj }
\usage{\method{info}{mylistobj}(object,info , ...)}
\arguments{
\item{...}{}
\item{info}{ info character. If missing function returns the current info. If not missing function returns mylistobj with new info field content.}
\item{object}{ mylistobj}
}
\details{ mylistobj provides basic functionality for objects implemented using list to store the attributes. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 res <- getrecalib(mv1)
 info(res)
 res<-info(res,"testname")
}
\keyword{misc}

\eof
\name{info.myobj}
\alias{info.myobj}
\title{ Info Acces}
\description{ access to the info field of the massvector. }
\usage{\method{info}{myobj}(object,info,...)}
\arguments{
\item{...}{}
\item{info}{ info character. If missing function returns the current info. If not missing function returns massvector with new info field content.}
\item{object}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 info(mv1)
 mv1<-info(mv1,"testname")
}
\keyword{misc}

\eof
\name{length.massvector}
\alias{length.massvector}
\title{ Length of Massvector}
\description{ get the Length of a Massvector }
\usage{\method{length}{massvector}(x,...)}
\arguments{
\item{...}{}
\item{x}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 length(mv1)
}
\keyword{misc}

\eof
\name{mass.massvector}
\alias{mass.massvector}
\title{ Mass Access.}
\description{ Access to the mass field of a massvector. }
\usage{\method{mass}{massvector}(object,mas,...)}
\arguments{
\item{...}{}
\item{mas}{ A array with masses. If missing function returns masses.}
\item{object}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 mass(mv1)
 mass(mv1,1:10)
}
\keyword{misc}

\eof
\name{massvector}
\alias{massvector}
\title{ Constructor}
\description{ massvector extends matrix }
\usage{massvector(info,masses,tcoor)}
\arguments{
\item{info}{ a unique identifier for the list.}
\item{masses}{ a matrix or a array with masses. First column must contain masses.}
\item{tcoor}{ a array of length two if integer sample support coordinates.}
}
\details{ The class massvector keeps the masses and their intensities in a matrix.  It stores additional attributes like the coordinates of the mass spectrometric sample on the support.  It also stores a identifier of the massvector. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 massvector("hello march",NULL)
 massvector("hello march",1:100)
 massvector("hello march",cbind(1:10,10:1))
 tmp<-cbind(1:10,1:10)
 colnames(tmp)<-c("mass","test")
 rr<-massvector("hello march",tmp)
 rr2<-massvector("hello bart",cbind(1:12,1:12))
 # plot functions for massvector
 plot(rr)
 hist(rr)
 summary(rr)
 image(rr)
 info(rr)
 # setting new masses
 mass(rr)
 mass(rr,1:10)
 peaks(rr,cbind(1:10,11:20))
 # plotting with masses
 data(mv1)
 data(mv2)
 plot(mv1,mv2)
 image(mv1  ,mv2)
 summary(mv1)
 print(mv1)
 hist(mv1)
 plot(mv1)
 image(mv1,mv2,error=199,ppm=FALSE)
}
\keyword{misc}

\eof
\name{massvectorlist}
\alias{massvectorlist}
\title{ Constructor}
\description{ constructor of object massvectorlist (extends list). }
\usage{massvectorlist(experiment,data,project,...)}
\arguments{
\item{...}{}
\item{data}{ list of massvectors}
\item{experiment}{ name of experiment}
\item{project}{ name of project.}
}
\value{
\item{ massvectorlist }{ object of class massvector.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 # testing constructor.
 massvectorlist("my1experiment")
 data(mvl)
 massvectorlist("my2experiment",mvl,"hello project")
 plot(mvl)
 summary(mvl)
 hist(mvl)
 hist(mvl)
 image(mvl,what="lengthmv")
 mvl2<-mvl[1:100]
 plot(mvl2)
 summary(mvl2)
 hist(mvl2)
 image(mvl2,what="lengthmv")
 #testing assingments
 mvl2[[11]]<-mvl2[[1]]
 plot(mvl2[[11]],mvl2[[1]])
 image(mvl2[[11]],mvl2[[1]])
 #make one massvector out of the peaklist
 tt<-unlist(mvl)
 plot(tt)
}
\keyword{misc}

\eof
\name{max.massvector}
\alias{max.massvector}
\title{ Maxima and Minima}
\description{ Returns the maxima and minima of the masses and intensities }
\usage{\method{max}{massvector}(mv,...)}
\arguments{
\item{...}{}
\item{mv}{ massvector}
}
\value{
\item{ named array with maxima of the columns of mv.}{}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{min.massvector}},
}
\keyword{misc}

\eof
\name{mget.massvector}
\alias{mget.massvector}
\title{ Field Access}
\description{ Access to the fields in the massvector }
\usage{\method{mget}{massvector}(object,attrn,...)}
\arguments{
\item{...}{ further parameters}
\item{attrn}{ The value of which field to return. If missing the fields of the objects are returned.}
\item{object}{ massvector}
}
\value{
\item{ xxx }{ depends which field in the massvector are accessed.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 mget(mv1,"info")
 mget(mv1,"peaks")
}
\keyword{misc}

\eof
\name{mget.mlist}
\alias{mget.mlist}
\title{ Field Access}
\description{ Acces fields in object of class myobj }
\usage{\method{mget}{mlist}(object,attrn,...)}
\arguments{
\item{...}{}
\item{attrn}{ name of field (Attribute)}
\item{object}{ object of class  mlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 mget(mvl)
 mget(mvl,"info")
 mget(mvl,"tcoor")
}
\keyword{misc}

\eof
\name{mget.mylistobj}
\alias{mget.mylistobj}
\title{ Field Access}
\description{ Access to the fields in the mylistobj }
\usage{\method{mget}{mylistobj}(object,attrn,...)}
\arguments{
\item{...}{ further parameters}
\item{attrn}{ The of the field to access. If missing the fields of the objects are returned.}
\item{object}{ mylistobj}
}
\details{ mylistobj provides basic functionality for objects implemented using list to store the attributes. }
\value{
\item{ xxx }{ depends which field in the massvector are accessed.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 res <- getrecalib(mv1)
 class(res)
 mget(mv1,"lenghtmv")
 mget(mv1,"Coef.Intercept")
}
\keyword{misc}

\eof
\name{mget.myobj}
\alias{mget.myobj}
\title{ Field Access}
\description{ Acces fields in object of class myobj }
\usage{\method{mget}{myobj}(object,attrn,...)}
\arguments{
\item{...}{}
\item{attrn}{ name of field (Attribute)}
\item{object}{ object of class myobj}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 mget(mv1)
 mget(mv1,"info")
}
\keyword{misc}

\eof
\name{min.massvector}
\alias{min.massvector}
\title{ Maxima and Minima}
\description{ Returns the maxima and minima of the masses and intensities }
\usage{\method{min}{massvector}(mv,...)}
\arguments{
\item{...}{}
\item{mv}{ massvector}
}
\value{
\item{ named array with minima of the columns of mv.}{}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{max.massvector}},
}
\keyword{misc}

\eof
\name{undocumented}
\alias{applycalib}
\alias{applyextcalib}
\alias{applyintcalib}
\alias{applyrecalib}
\alias{calibexternal}
\alias{compare}
\alias{correctinternal}
\alias{diffFilter}
\alias{distance}
\alias{experiment}
\alias{FullWidthatHalfMaximum}
\alias{gamasses}
\alias{getcalib}
\alias{getdiff}
\alias{getextcalib}
\alias{getglobalcalib}
\alias{getintcalib}
\alias{getrecalib}
\alias{globalcalib.default}
\alias{globalcalib}
\alias{info}
\alias{join.default}
\alias{join}
\alias{mass}
\alias{mget}
\alias{mmod}
\alias{mod}
\alias{mvFilter}
\alias{peaks.default}
\alias{peaks}
\alias{project}
\alias{readBruker}
\alias{recalibrate}
\alias{setcalib}
\alias{wsdist}
\alias{wsiFilter}
\alias{wsFilter}
\alias{writeF}
\alias{readF}
\alias{as.lm}
\alias{setParms<-}
\title{Undocumented functions}
\description{These functions are undocumented. Some are internal and not intended for direct use. Some are not yet ready for end users. Others simply haven't been documented yet.}
\usage{}
\author{Witold E. Wolski}
\keyword{internal}

\eof
\name{mv1}
\docType{data}                                               
\alias{mv1}
\alias{mv2}                                      
\title{Massvector with experimentally determined peptide masses.}           
\usage{data(mv1)}   
\description{}                                                                                     
\author{Witold E. Wolski}                                   
\keyword{datasets}                                              

\eof
\name{mvFilter.massvector}
\alias{mvFilter.massvector}
\title{ Filtering Massvector}
\description{ Filters massvector for masses given in a second massvector. }
\usage{\method{mvFilter}{massvector}(object,fmass,match=FALSE,error=250,ppm=TRUE,uniq=FALSE,...)}
\arguments{
\item{...}{}
\item{error}{ mesurment error.}
\item{fmass}{}
\item{match}{ logical; \code{TRUE} - than returns masses matching to the masses in massvector abundant, \code{FALSE} - returns masses not matching.}
\item{object}{ massvector}
\item{ppm}{ given either in ppm (\code{TRUE}) or as absolut error (F).}
\item{uniq}{ logical; \code{FALSE} - returns all masses in the range given by error. \code{TRUE} - returns only the closest mass.}
}
\value{
\item{ massvector }{ with matching or not matchin masses.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 data(mv2)
 mvFilter(mv1,mv2,error=250,match=FALSE)
 mvFilter(mv1,mv2,error=250,match=TRUE)
}
\keyword{misc}

\eof
\name{mvFilter.massvectorlist}
\alias{mvFilter.massvectorlist}
\title{ Filtering Massvector}
\description{ Filters massvector for masses given in a second massvector. }
\usage{\method{mvFilter}{massvectorlist}(object,fmass,match=FALSE,error=250,ppm=TRUE,uniq=FALSE,...)}
\arguments{
\item{...}{ further parameters.}
\item{error}{ mesurment error.}
\item{fmass}{}
\item{match}{ logical;\code{TRUE} - than returns masses matching to the masses in massvector abundant, \code{FALSE} - returns masses not matching.}
\item{object}{ massvectorlist}
\item{ppm}{ given either in ppm (\code{TRUE}) or as absolut error (\code{FALSE}).}
\item{uniq}{ logical; \code{FALSE} - returns or removes all masses in the range given by error. \code{TRUE} - returns ore removes only the closest mass.}
}
\value{
\item{ massvectorlist }{ with massvectors with matching or not matching masses.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{mvFilter.massvector}},
}
\examples{
 data(mvl)
 mvl<-mvFilter(mvl,mvl[[1]],match=FALSE,error=250)
 length(mvl[[1]])
}
\keyword{misc}

\eof
\name{mvl}
\docType{data}
\alias{mvl}
\title{A list of 333 massvectors with experimentally determined peptide masses.}      
\usage{data(mvl)}
\description{}                           
\author{Witold E. Wolski}           
\keyword{datasets}      

\eof
\name{mvll}
\docType{data}
\alias{mvll}
\title{A list of 333 massvectors with experimentally determined peptide masses.}

\usage{data(mvl)}
\description{}
\seealso{\code{\link{mvl}}}                       
\author{Witold E. Wolski}           
\keyword{datasets}      

\eof
\name{peaks.massvector}
\alias{peaks.massvector}
\title{ Data Access}
\description{ Access to the mass field of the massvector. }
\usage{\method{peaks}{massvector}(object,masses,...)}
\arguments{
\item{...}{}
\item{masses}{ matrix with masses in first column. If missing the matrix of the massvector is returned.}
\item{object}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{mass.massvector}},
}
\examples{
 mv1<-massvector()
 mv1<- peaks(mv1,cbind(1:10,1:10))
 peaks(mv1)
}
\keyword{misc}

\eof
\name{plot.calibintlist}
\alias{plot.calibintlist}
\title{ Calibintlist Plotting}
\description{ A matrix of scatterplots is produced. }
\usage{\method{plot}{calibintlist}(x,...)}
\arguments{
\item{...}{ graphical parameters can be given as arguments to plot.}
\item{x}{ object of class calibintlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 data(cal)
 mvl <- mvl[1:100]
 ires <- getintcalib(mvl,cal,error=250)
 plot(ires)
}
\keyword{misc}

\eof
\name{plot.calibintstat}
\alias{plot.calibintstat}
\title{ Calibinstat Plotting}
\description{ Plots a line with intercept and slope given by the error model. }
\usage{\method{plot}{calibintstat}(x,...)}
\arguments{
\item{...}{ graphical parameters can be given as arguments to plot.}
\item{x}{ object of class calibintstat}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 data(cal)
 res<-getintcalib(mv1,cal,error=500,ppm=TRUE)
 plot(res)
}
\keyword{misc}

\eof
\name{plot.caliblist}
\alias{plot.caliblist}
\title{ plot}
\description{ plot }
\usage{\method{plot}{caliblist}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class caliblist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{plot.calibrelist}
\alias{plot.calibrelist}
\title{ Plot}
\description{ Shows a matrix of scatterplots for different varialbes.. }
\usage{\method{plot}{calibrelist}(x,...)}
\arguments{
\item{...}{ graphical parameters can be given as arguments to plot.}
\item{x}{ calibrelist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 res2 <- getrecalib(mvl) # get recalibration model for not filtered data
 plot(res2)
}
\keyword{misc}

\eof
\name{plot.calibspline}
\alias{plot.calibspline}
\title{ Calibspline Plotting}
\description{ Function for plotting object of class calibspline. }
\usage{\method{plot}{calibspline}(x,...)}
\arguments{
\item{...}{ graphical parameters can be given as arguments to `plot'.}
\item{x}{ calibspline}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(ppg)
 tmp <- getextcalib(ppg,error=200)
 plot(tmp)
}
\keyword{misc}

\eof
\name{plot.calibstat}
\alias{plot.calibstat}
\title{ plot}
\description{ plot }
\usage{\method{plot}{calibstat}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class calibstat}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{plot.massvector}
\alias{plot.massvector}
\title{ Massvector Plotting}
\description{ Function for plotting massvectors. If one massvector are given it shows a stick masspectrum.  If two massvectors are given their masses are plotted against each other. }
\usage{\method{plot}{massvector}(x,...)}
\arguments{
\item{...}{ a second massvector and graphical parameters can be given as arguments to `plot'.}
\item{x}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 data(mv2)
 plot(mv1)
 plot(mv1,mv2)
}
\keyword{misc}

\eof
\name{plot.massvectorlist}
\alias{plot.massvectorlist}
\title{ Massvectorlist Plotting}
\description{ Plots masses (m/z) in massvector against sample in massvectorlist. }
\usage{\method{plot}{massvectorlist}(x, main=info(mvl) ,xlab="m/z",xlim=c(700,4500),add=FALSE,col=1,cex=0.5,...)}
\arguments{
\item{...}{ graphical parameters can be given as arguments to `plot'.}
\item{add}{ \code{TRUE} - masses of a new massvectorlist are added to existing plot.}
\item{cex}{}
\item{col}{ color of the points denoting the masses.}
\item{main}{ an overall title for the plot.}
\item{x}{ massvectorlist}
\item{xlab}{ a title for the x axis.}
\item{xlim}{ the range to be encompassed by the x axis.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{hist.massvectorlist}},
\code{\link{plot.massvector}},
\code{\link{image.mlist}},
\code{\link{plot}},
\code{\link{par}},
}
\examples{
 data(mvl)
 plot(mvl,col= 3 )
 tt<- gamasses(mvl,abund=50)
 plot(mvl,col=1, xlim=c(tt[1,1]-0.4,tt[1,1]+0.4))
}
\keyword{misc}

\eof
\name{plot.mylistobj}
\alias{plot.mylistobj}
\title{ plot}
\description{ plot }
\usage{\method{plot}{mylistobj}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class mylistobj}
}
\details{ mylistobj provides basic functionality for objects implemented using list to store the attributes. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{ppg}
\docType{data}                     
\alias{ppg}
\title{A list of 12 massvectors wiht ppg masses.}
\usage{data(mvl)}   
\description{}                                
\author{Witold E. Wolski}         
\keyword{datasets}     

\eof
\name{print.calibintstat}
\alias{print.calibintstat}
\title{ Print calibintstat}
\description{ `print' prints its argument and returns it invisibly (via `invisible(x)') }
\usage{\method{print}{calibintstat}(x,...)}
\arguments{
\item{...}{}
\item{x}{ calibintstat object}
}
\value{
\item{ info }{ the id of the massvector}
\item{ type }{ type of error}
\item{ Intercept }{ Intercept of the mass dependent error}
\item{ Slope }{ The slope of the mass dependent error}
\item{ Lenght pl }{ Lenght of the peaklist}
\item{ mean }{ mean of the error}
\item{ stdv }{ stdv of the error}
\item{ nrmatch }{ nr matches.}
\item{ Xcoor }{ x coordinate on sample support}
\item{ Ycoor }{ y coordinate on sample support}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 data(cal)
 res<-getintcalib(mv1,cal,error=500,ppm=TRUE)
 print(res)
}
\keyword{misc}

\eof
\name{print.caliblist}
\alias{print.caliblist}
\title{ Print caliblist}
\description{ `print' prints its argument and returns it invisibly (via `invisible(x)') }
\usage{\method{print}{caliblist}(x,...)}
\arguments{
\item{...}{}
\item{x}{ caliblist}
}
\value{
\item{ list }{ list}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 data(cal)
 test <- getintcalib(mvl,cal,error=500)
 print(test)
}
\keyword{misc}

\eof
\name{print.calibrestat}
\alias{print.calibrestat}
\title{ Print Calibrestat Object}
\description{ Prints the fields of the calibrestat object. }
\usage{\method{print}{calibrestat}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class calibrestat}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{print}},
}
\examples{
 data(mv1)
 res<-getrecalib(mv1)
 print(res)
}
\keyword{misc}

\eof
\name{print.calibspline}
\alias{print.calibspline}
\title{ Print Calibspline Object}
\description{ `print' prints its argument and returns it invisibly (via `invisible(x)') }
\usage{\method{print}{calibspline}(x,...)}
\arguments{
\item{...}{}
\item{x}{ calibspline}
}
\value{
\item{ info }{ the id of the calibspline}
\item{ smooth.spline }{ smooth.spline}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(ppg)
 tmp <- getextcalib(ppg,error=200)
 print(tmp)
}
\keyword{misc}

\eof
\name{print.calibstat}
\alias{print.calibstat}
\title{ print}
\description{ print }
\usage{\method{print}{calibstat}(x,...)}
\arguments{
\item{...}{}
\item{x}{ object of class calibstat}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\keyword{misc}

\eof
\name{print.massvector}
\alias{print.massvector}
\title{ Print massvector}
\description{ `print' prints its argument and returns it invisibly (via `invisible(x)') }
\usage{\method{print}{massvector}(x,quote=FALSE,...)}
\arguments{
\item{...}{}
\item{quote}{}
\item{x}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link[base]{print}},
}
\examples{
 data(mv1)
 print(mv1)
}
\keyword{misc}

\eof
\name{print.massvectorlist}
\alias{print.massvectorlist}
\title{ Print massvectorlist}
\description{ `print' prints its argument and returns it invisibly (via `invisible(x)') }
\usage{\method{print}{massvectorlist}(x,...)}
\arguments{
\item{...}{}
\item{x}{ massvectorlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link[base]{print}},
}
\examples{
 data(mvl)
 print(mvl)
}
\keyword{misc}

\eof
\name{project.massvectorlist}
\alias{project.massvectorlist}
\title{ Acces}
\description{ Access to the project field of the massvectorlist. }
\usage{\method{project}{massvectorlist}(object,project,...)}
\arguments{
\item{...}{ further arguments}
\item{object}{ massvectorlist}
\item{project}{ info character. If missing function returns the current info. If not missing function returns massvector with new project field content.}
}
\details{ Can be used for setting or getting the project field. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{info.mlist}},
\code{\link{experiment.mlist}},
}
\examples{
 data(mvl)
 project(mvl)
 mvl <- project(mvl,"newprojectname")
}
\keyword{misc}

\eof
\name{readF.massvector}
\alias{readF.massvector}
\title{ Read Massvector}
\description{ Reads massvector written with the function \code{writeF.massvector} }
\usage{\method{readF}{massvector}(object,path,file=info(object),ext="txt",...)}
\arguments{
\item{...}{}
\item{ext}{ file extension; default }
\item{file}{ file name; default }
\item{object}{ object of class massvector. Use constructor \code{massvector()}}
\item{path}{ path to file.}
}
\details{ The read and write functions for all the different peak-list formats are not provided by the package. This is because  there are oodles of different formats. I will try to collect read-write functions for as many as possible peak-list format's in an add on package  which you can find at \url{http://www.molgen.mpg.de/~wolski/mscalib/IO/}.  The file format of the file to be read must be:  \code{>0_A1_1SRef:1,1}  \code{842.4257236	650.66}  \code{987.3931319	180.3}  \code{...  ...}  The char between > and : is read into the info field and used as a key in the massvectorlist. So it must be unique.  After the double colon the coordinates have to written.  The first column are the masses. The second column are the intensities. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{writeF.massvector}},
}
\examples{
 data(mv1)
 writeF(mv1,".")
 readF(massvector(info(mv1)),".")
 file.remove(paste(info(mv1),".txt",sep=""))
}
\keyword{misc}

\eof
\name{readF.massvectorlist}
\alias{readF.massvectorlist}
\title{ Reads massvectorlist}
\description{ written to disk with \code{writeF.massvectorlist} }
\usage{\method{readF}{massvectorlist}(object,path,file=experiment(object),ext="txt",...)}
\arguments{
\item{...}{}
\item{ext}{}
\item{file}{ file to read. default =experiment(object)}
\item{object}{massvectorlist}
\item{path}{ path to directory.}
}
\details{ The read and write functions for all the different peak-list formats are not provided by the package. This is because  there are oodles of different formats. I will try to collect read-write functions for as many as possible peak-list format's in an add on package  which you can find at \url{http://www.molgen.mpg.de/~wolski/mscalib/IO/}. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{readF.massvector}},
\code{\link{writeF.massvectorlist}},
}
\examples{
 data( mvl )
 mvl
 writeF( mvl , "." )
 test <- readF(massvectorlist(info(mvl)),".")
 test
 unlink(paste(info(test),".txt",sep=""))
}
\keyword{misc}

\eof
\name{recalibrate.massvector}
\alias{recalibrate.massvector}
\title{ Precalibration}
\description{ Obtains the error and performs the calibration in one step. }
\usage{\method{recalibrate}{massvector}(object,PQM=7,...)}
\arguments{
\item{...}{ further parameters}
\item{PQM}{ Peak Quality Measure. Indicates how well the wavelenght of the massvector was determined.}
\item{object}{ massvector}
}
\details{ Precalibration method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the massesvector can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. {\em Proteomics.} 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 mv2<-recalibrate(mv1)
 plot(mv1[,1],mv1[,1]-mv2[,1],type="l")
}
\keyword{misc}

\eof
\name{recalibrate.massvectorlist}
\alias{recalibrate.massvectorlist}
\title{ Precalibration}
\description{ Obtains the error and performs the calibration in one step. }
\usage{\method{recalibrate}{massvectorlist}(object,PQM=7,...)}
\arguments{
\item{...}{ further parameters.}
\item{PQM}{ Peak Quality Measure. Indicates how well the wavelenght of the massvector was determined.}
\item{object}{ massvectorlist.}
}
\details{ Precalibration method utilizes the knowledge that masses  of peptides are in equidistant spaced clusters. The wavelength of  the massesvector can be determined as described by  Wool. The comparision of the experimental wavelength with  the theoretical one, makes possible to find an affine function  that corrects the masses. Chemical noise in the spectra may hamper  the determination of mass list frequency. The package provides a  function to filter chemical noise. }
\value{
\item{ massvectorlist }{ recalibrated massvectorlist.}
}
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. Proteomics. 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{recalibrate.massvector}},
}
\examples{
 data(mvl)
 mvl<-mvl[1:100]
 pp <- recalibrate(mvl,PQM=8)
 compare(pp[[1]],mvl[[1]],error=1,ppm=FALSE)
}
\keyword{misc}

\eof
\name{residuals.massvector}
\alias{residuals.massvector}
\title{ Residues of 2 massvectors.}
\description{ Computes Residues of 2 massvectors. }
\usage{\method{residuals}{massvector}(object,fmass,error=250,ppm=TRUE,uniq=TRUE,...)}
\arguments{
\item{...}{}
\item{error}{ the assumed difference between the aligned peaks either in ppm or in Da.}
\item{fmass}{ object of class massvector.}
\item{object}{ object of class massvector. Use constructor \code{massvector()}}
\item{ppm}{ logical; if TRUE then the error must be specified in ppm.}
\item{uniq}{}
}
\details{ Computes the mass differences between aligned masses of two massvectorlists. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{getaccC}},
\code{\link{compare}},
}
\examples{
 data(mv1)
 data(mv2)
 plot(resid(mv1,mv2,error=250,uniq=TRUE))
}
\keyword{misc}

\eof
\name{setParms<-.mylistobj}
\alias{setParms<-.mylistobj}
\title{ Field Access}
\description{ Set attributes in object of class mylistobj }
\usage{}
\arguments{
\item{object}{ object of class myobj}
\item{value}{ a list where list names are attributes names.}
}
\details{ mylistobj provides basic functionality for objects implemented using list to store the attributes. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{setParms<-.myobj}},
\code{\link{mget.mylistobj}},
}
\examples{
 data(mv1)
 res<-getrecalib(mv1)
 setParms(res) <- list(info="test")
 res
}
\keyword{misc}

\eof
\name{setParms<-.myobj}
\alias{setParms<-.myobj}
\title{ Field Access}
\description{ Set attributes in object of class myobj }
\usage{}
\arguments{
\item{object}{ object of class myobj}
\item{value}{ a list where list names are attributes names.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 mv1
 setParms(mv1) <- list(info="test")
 mv1
}
\keyword{misc}

\eof
\name{subset.mlist}
\alias{subset.mlist}
\title{ Subset mlist}
\description{ Return subsets of list elements which meet conditions. }
\usage{\method{subset}{mlist}(x,subset,...)}
\arguments{
\item{...}{}
\item{subset}{ logical expression.}
\item{x}{ object of class mlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mvl)
 mvl<-subset(mvl,lengthmv>30)
}
\keyword{misc}

\eof
\name{summary.calibintstat}
\alias{summary.calibintstat}
\title{ Calibintstat Summaries}
\description{ Generates a summary: info, Intercept, Slope etc. for object of class calibintastat }
\usage{\method{summary}{calibintstat}(object,...)}
\arguments{
\item{...}{ further parameters.}
\item{object}{ calibinstat.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{summary}},
}
\examples{
 data(mv1)
 data(cal)
 res<-getintcalib(mv1,cal,error=500,ppm=TRUE)
 summary(res)
}
\keyword{misc}

\eof
\name{summary.calibspline}
\alias{summary.calibspline}
\title{ Calibspline Summaries}
\description{ Generates a summary, min, max etc. }
\usage{\method{summary}{calibspline}(object,...)}
\arguments{
\item{...}{}
\item{object}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{summary}},
}
\examples{
 data(ppg)
 tmp <- getextcalib(ppg,error=200)
 summary(tmp)
}
\keyword{misc}

\eof
\name{summary.calibstat}
\alias{summary.calibstat}
\title{ Calibstat summary}
\description{ Generates Summary. }
\usage{\method{summary}{calibstat}(object,...)}
\arguments{
\item{...}{}
\item{object}{ object of class calibstat.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\examples{
 data(mv1)
 data(cal)
 test<-getintcalib(mv1,cal)
 summary(test)
}
\keyword{misc}

\eof
\name{summary.massvector}
\alias{summary.massvector}
\title{ Massvector Summaries}
\description{ Generates a summary: min, max etc. }
\usage{\method{summary}{massvector}(object,...)}
\arguments{
\item{...}{}
\item{object}{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{summary}},
}
\keyword{misc}

\eof
\name{summary.mlist}
\alias{summary.mlist}
\title{ mist Summaries}
\description{ Generates a summary for the data.frame generated by as.data.frame.mlist }
\usage{\method{summary}{mlist}(object,...)}
\arguments{
\item{...}{ further arguments}
\item{object}{ mlist}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{summary.massvector}},
\code{\link{as.data.frame.mlist}},
}
\examples{
 data(mvl)
 summary(mvl)
 data(mvl)
 mvl<-mvl[1:100] 
 data(cal)
 test <- getintcalib(mvl,cal,error=500)
 summary(test)
}
\keyword{misc}

\eof
\name{unlist.massvectorlist}
\alias{unlist.massvectorlist}
\title{ Flatten massvectorlist}
\description{  Given a list structure `x', `unlist' simplifies it to produce a   massvector which contains all the atomic components which occur in x. }
\usage{\method{unlist}{massvectorlist}(x,...)}
\arguments{
\item{...}{ further arguments.}
\item{x}{ massvectorlist.}
}
\value{
\item{ massvector }{ massvector}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link[base]{unlist}},
}
\examples{
 data(mvl)
 amv <- unlist(mvl)
 length(amv)
}
\keyword{misc}

\eof
\name{writeF.massvector}
\alias{writeF.massvector}
\title{ Write massvector}
\description{ Write massvector to File. }
\usage{\method{writeF}{massvector}(object,path,file=info(object),ext="txt",...)}
\arguments{
\item{...}{}
\item{ext}{ file extension.}
\item{file}{ file name. defualt info(object)}
\item{object}{ massvector}
\item{path}{ path to folder.}
}
\details{ The read and write functions for different peak-list formats are not provided by the package. This is because  there are a oodles of different formats. I will try to collect read-write functions for as many as possible peak-list format's in an add on package  which you can find at \url{http://www.molgen.mpg.de/~wolski/mscalib/IO/}. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{writeF.massvectorlist}},
\code{\link{readF.massvector}},
}
\examples{
 data(mv1)
 writeF(mv1,".") # writes the file in the home directory.
 readF(massvector(info(mv1)),".")
 file.remove(paste(info(mv1),".txt",sep=""))
}
\keyword{misc}

\eof
\name{writeF.massvectorlist}
\alias{writeF.massvectorlist}
\title{ Write massvectorlist}
\description{ Write massvectorlist to File }
\usage{\method{writeF}{massvectorlist}(object,path,file=experiment(object),ext="txt",...)}
\arguments{
\item{...}{}
\item{ext}{ file extension. default txt.}
\item{file}{ file name. default experiment(object)}
\item{object}{ massvectorlist.}
\item{path}{ path to directory.}
}
\details{ The read and write functions for all the different peak-list formats are not provided by the package. This is because  there are oodles of different formats. I will try to collect read-write functions for as many as possible peak-list format's in an add on package  which you can find at \url{http://www.molgen.mpg.de/~wolski/mscalib/IO/}. }
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{readF.massvectorlist}},
\code{\link{readF.massvector}},
}
\keyword{misc}

\eof
\name{wsFilter.massvector}
\alias{wsFilter.massvector}
\title{ Smilanski Filtering}
\description{ Removes chemical noise from the massvectorlist. }
\usage{\method{wsFilter}{massvector}(object,mdist=0.25,fraction=0.2, peptides=TRUE,...)}
\arguments{
\item{...}{ further parameters.}
\item{fraction}{ maximal size of branche (nr masses in branch)/(length of massvector) to be cut.}
\item{mdist}{ minimal distance of branch to be cut.}
\item{object}{ massvector.}
\item{peptides}{ \code{TRUE} - returns peptides, \code{FALSE} - returns chemical noise.}
}
\details{ Chemical noise can be removed from the peptide mass lists  due to the strong clustering of mono-isotopic peptide  peaks. Following the distance measure and filtering  method proposed by Wool Smilanski we developed an algorithm to  classify masses as peptide and non-peptide. The algorithm is based  on a modified distance measure and hierarchical clustering of all  intra massvector distances. }
\value{
\item{ massvector }{  returns either a massvector of nonpeptide masses or massvector of peptide masses.}
}
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. Proteomics. 2(10):1365-73.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{wsiFilter.massvector}},
\code{\link{wsFilter.massvectorlist}},
}
\examples{
 data(mv1)
 tmp <- wsFilter(mv1,peptide=FALSE)
 plot(tmp)
 tmp <- wsFilter(mv1,peptide=TRUE)
 plot(tmp)
}
\keyword{misc}

\eof
\name{wsFilter.massvectorlist}
\alias{wsFilter.massvectorlist}
\title{ Smilanski Filtering}
\description{ Removes chemical noise from massvectors in the massvectorlist (if \code{peptides} argument \code{TRUE}) or returns it. }
\usage{\method{wsFilter}{massvectorlist}(object,mdist=0.25,fraction=0.2, peptides=TRUE,... )}
\arguments{
\item{...}{ further parameters.}
\item{fraction}{ Maximal fraction (nr masses in branch)/(length of massvector) of branche to be prune.}
\item{mdist}{ Minimal distance to branch to prune. The unit of the distance is Dalton.}
\item{object}{ massvectorlist.}
\item{peptides}{ logical; \code{TRUE} - returns peptides, \code{FALSE} - returns chemical noise.}
}
\details{ Chemical noise can be removed from the peptide mass lists  due to the strong clustering of mono-isotopic peptide  peaks. Following the distance measure and filtering  method proposed by Wool Smilanski we developed an algorithm to  classify masses as peptide and non-peptide. The algorithm is based  on a modified distance measure and hierarchical clustering of all  intra massvector distances. }
\value{
\item{ massvectorlist }{  Returns a massvectorlist where the massvectors either contain the peptides or the non-peptides.}
}
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. Proteomics. 2(10):1365-73.}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{wsiFilter.massvector}},
\code{\link{wsFilter.massvector}},
}
\examples{
 data(mvl)
 res <- wsFilter(mvl,peptides = TRUE)
 plot(res)
 res2 <- wsFilter(mvl,peptides = FALSE)
 plot(res2,col=2,add=TRUE)
 image(res2,what="lengthmv")
 hist(res)
 hist(res2,col=2,add=TRUE)
}
\keyword{misc}

\eof
\name{wsdist.massvector}
\alias{wsdist.massvector}
\title{ Wool Smilanski Distance Matrix}
\description{ This function computes and returns the distance matrix  using the intra massvecotor distance  measure. }
\usage{\method{wsdist}{massvector}(object,...)}
\arguments{
\item{...}{}
\item{object}{ massvector}
}
\value{
\item{ dist }{ an object of class distance.}
}
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. \emph{Proteomics.} 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{wsFilter.massvector}},
\code{\link{wsiFilter.massvector}},
}
\examples{
 data(mv1)
 plot(hclust(wsdist(mv1),method="single"))
}
\keyword{misc}

\eof
\name{wsiFilter.massvector}
\alias{wsiFilter.massvector}
\title{ Smilanski Filtering}
\description{ The function returns the inidces of masses identified as chemical noise. }
\usage{\method{wsiFilter}{massvector}(object , mdist=0.25 , fraction=0.2 , ... )}
\arguments{
\item{...}{ further arguments.}
\item{fraction}{ maximal fraction (nr masses in branch)/(length of massvector) of branche  to be prune.}
\item{mdist}{ minimal distance to branch to be prune. The unit of this distance are Daltons.}
\item{object}{ massvector.}
}
\details{ Chemical noise can be removed from the peptide mass lists  due to the strong clustering of mono-isotopic peptide  peaks. Following the distance measure and filtering  method proposed by Wool Smilanski we developed an algorithm to  classify masses as peptide and non-peptide. The algorithm is based  on a modified distance measure and hierarchical clustering of all  intra massvector distances. }
\value{
\item{ indices }{  Indices of masses which are identified as being nonpeptide.}
}
\references{\item{-}{ Wool A, Smilansky Z 2002. Precalibration of matrix-assisted laser desorption/ionization-time of flight spectra for peptide mass fingerprinting. \emph{Proteomics.} 2(10):1365-73.}
\item{-}{Wolski \url{http://www.molgen.mpg.de/~wolski/mscalib}}
}
\author{Witold Wolski \email{wolski@molgen.mpg.de}}
\seealso{\code{\link{wsFilter.massvector}},
\code{\link{wsdist.massvector}},
\code{\link{wsFilter.massvectorlist}},
}
\examples{
 data(mv1)
 data(mv2)
 length(mv1)
 length(wsFilter(mv1))
 length(mv2)
 length(wsFilter(mv2))
}
\keyword{misc}

\eof
